function [ lower, upper, pT, lT, uT, beta_hat, sigma_hat ] = GPreach(input,obs,obs1,kernel,grid,options,basisFunc,dBasisFunc)
%GPpredTraj Computes the GP prediction with radial basis kernel
%using the non-informative prior on amplitude according to O'Hagan 2004
%for each point of a sampled trajectory in discrete time
%   input - input points, arranged in a n x dim matrix
%   coord - which coordinate to compute
%   obs - observations, a m x n x p tensor.
%   obs1 - derivatives fo observations w.r.t. input parameters. 
%          a m x dim x n x p tensor
%   lengthscale - a vector with the lengthscale (per coord)
%   grid - the points in which to compute the prediction

h = size(grid,1);
uT = zeros(1,h);
lT = zeros(1,h);
pT = zeros(1,h);

rm = GPregressionM(input,obs,obs1,kernel,options,basisFunc,dBasisFunc);
beta_hat = rm.beta_hat;
sigma_hat = rm.sigma_hat;
for i=1:h
    [p,l,u] = rm.predict(grid(i,:),rm);
%     disp(['prediction'])
%     disp( num2str(p));
%     disp(['lower'])
%     disp( num2str(l));
%     disp(['upper'])
%     disp( num2str(u));
    uT(i) = u;
    lT(i) = l;
    pT(i) = p;
end
lower = real(min(lT)); 
upper = real(max(uT));


 

end

