function [ amp,ls ] = hyperparOpt( input,obs,kernel,options,range,obs_noise);
%hyperparOpt optimises (some) hyperparameters of the kernel.
    
    n = size(input,1);
    if nargin <=5
        obs_noise = options.noise_level;
    end

    ind = logical([kernel.optimiseAmplitude;kernel.optimiseLenghtscale]);
    opt = optimset('Algorithm','interior-point','Display','off');
    best = [];
    maxLM = -Inf;
    disp('Hyperparameter optimisation');
    for i=1:options.hyperparOptMultipleStarts
         disp(['run ', int2str(i)]);    
         x0 = randompoint(kernel,range);
         id = tic;
         [x,f] =  fmincon(@otpfunc,x0,[],[],[],[],range(ind,1),range(ind,2),[],opt);
         t = toc(id);
         disp(['Completed in time ', num2str(t) ]);
         if -f > maxLM
             disp(['New optimal solution found. ']);
             disp(num2str(x));
             best = x;
             maxLM = -f;
         end
    end
    [amp,ls] = getHyperparameters(best);
        
    
    
    
    function [a,l] = getHyperparameters(x)
       offset=0; 
       if kernel.optimiseAmplitude
           a = x(1);
           offset=1;
       else
           a = kernel.amplitude;
       end
       l = zeros(kernel.dim,1);
       for j=1:kernel.dim
           if kernel.optimiseLenghtscale(j)
                l(j) =  x(offset+j);
           else
               l(j) = kernel.lengthscale(j);
           end
       end 
    end



    function y = otpfunc(x)
       [a,l] = getHyperparameters(x);
       kernel.amplitude = a;
       kernel.lengthscale = l;
       rm = GPregression(input,obs,kernel,options,obs_noise);
       y = -rm.logmarginal;   
    end

    function x = randompoint(kernel,range)
        xs = unifrnd(range(:,1),range(:,2));
        x = xs(ind);
    end


end

