function [ xmax, maxGP ] = GPUCB_localOpt( rm,beta,initpoint,domain)
%GPUCB_localOpt Finds the local maximum of the GP-UCB opt function
%starting from initpoint, using the built-in matlab optimisation method.
%Returns the new maximum, the value in the max point

if domain.standardise
    range = domain.range;
else
    range = domain.trueRange;
end

%options for constrained minimisation
options = optimset('GradObj','on','Algorithm','interior-point',...
    'Display','off');

[xmax,fval] = fmincon(@GP_UCB_func,initpoint,[],[],[],[],...
   range(:,1),range(:,2),[],options);
maxGP = -fval;


function [f,G] = GP_UCB_func(point)
    [p,std,dp,dstd] = rm.predictGradient(point,rm);
    f = p + beta*std;
    G = dp + beta*dstd;
end

   

end




% 
% 
% converged = 0;
% iterations = 0;
% 
% while ~converged
%     g = gradient(point);
%     H = hessian(point);
%     p = H\g;
%     oldpoint = point;
%     point = point - p;
%     if norm(oldpoint-point) < 1e-6
%         converged = 1;
%     end
%     iterations = iterations + 1;
% end
% 
% 
% if params.standardise
%     xmax = params.invStdF(point,params);
% else
%     xmax = point;
% end
% maxGP = GPmean(point);
% Hessian = hessian(point);
% 
% 






%     function H = hessian(point) 
%         H = zeros(n);
%         for i=1:n
%             for j=1:n
%                 v = zeros(1,m);
%                 for k = 1:m
%                     v(k) = kernel.SDfunction(point,input(:,k),i,j,kernel);
%                 end
%                 H(i,j) = v*aux;
%             end
%         end
%     end
% 
%     function G = gradient(point)
%         G = zeros(n,1);
%         for i=1:n
%             v = zeros(1,m);
%             for k = 1:m
%                 v(k) = kernel.gradfunction(point,input(:,k),i,kernel);
%             end
%             G(i) = v*aux;
%         end
%     end
% 
%     function f = GPmean(point) 
%         v = zeros(1,m);
%         for k = 1:m
%             v(k) = kernel.function(point,input(:,k),kernel);
%         end
%         f = v*aux;
%         end
%     end




